package singletonPattern;

/**
 * 懒汉式
 * @author chenda
 */
public class SingletonL {

    private volatile static SingletonL singleton;

    private SingletonL() {

    }

    /**
     * 加锁保证只会被实例化一次
     * @return singleton
     */
    public synchronized static SingletonL getInstance() {
        if (singleton == null) {
            singleton = new SingletonL();
        }
        return singleton;
    }

    /**
     * 双重锁 减少同步范围
     * @return
     */
    public static SingletonL getInstanceDoubleLock() {
        if (singleton == null) {
            synchronized (SingletonL.class) {
                if (singleton == null) {
                    singleton = new SingletonL();
                }
            }
        }
        return singleton;
    }
}
